======
cfglib
======

.. image:: https://img.shields.io/pypi/v/cfglib.svg
        :target: https://pypi.python.org/pypi/cfglib

.. image:: https://img.shields.io/travis/swarmer/cfglib.svg
        :target: https://travis-ci.org/swarmer/cfglib

.. image:: https://readthedocs.org/projects/cfglib/badge/?version=latest
        :target: https://cfglib.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


An extensible configuration library


* Free software: MIT license
* Documentation: https://cfglib.readthedocs.io.


Features
--------

- TODO
